@@ -15,6 +15,8 @@
 import flask_restful
 
 from keystone.api._shared import implied_roles as shared
+from keystone.api import validation
+from keystone.assignment import schema
 from keystone.common import provider_api
 from keystone.common import rbac_enforcer
 from keystone.server import flask as ks_flask
@@ -24,6 +26,10 @@ PROVIDERS = provider_api.ProviderAPIs
 
 
 class RoleInferencesResource(flask_restful.Resource):
+    @validation.request_body_schema(None)
+    @validation.response_body_schema(
+        schema.role_inferences_index_response_body
+    )
     def get(self):
         """List role inference rules.
 
@@ -36,7 +42,7 @@ class RoleInferencesResource(flask_restful.Resource):
             for role_ref in PROVIDERS.role_api.list_roles()
         }
 
-        rules = dict()
+        rules = {}
         for ref in refs:
             implied_role_id = ref['implied_role_id']
             prior_role_id = ref['prior_role_id']
@@ -49,10 +55,7 @@ class RoleInferencesResource(flask_restful.Resource):
             rules[prior_role_id] = implied
 
         inferences = []
-        for (
-            prior_id,
-            implied,
-        ) in rules.items():
+        for prior_id, implied in rules.items():
             prior_response = shared.build_prior_role_response_data(
                 prior_id, role_dict[prior_id]['name']
             )
