@@ -26,7 +26,6 @@ PROVIDERS = provider_api.ProviderAPIs
 
 
 class Bootstrapper:
-
     def __init__(self):
         backends.load_backends()
 
@@ -310,8 +309,7 @@ class Bootstrapper:
             )
         except exception.Conflict:
             LOG.info(
-                'User %(username)s already has role %(role)s on '
-                'the system.',
+                'User %(username)s already has role %(role)s on the system.',
                 {
                     'username': self.admin_username,
                     'role': self.admin_role_name,
