@@ -28,77 +28,77 @@ deprecated_check_policy_assoc_for_endpoint = policy.DeprecatedRule(
     name=base.IDENTITY % 'check_policy_association_for_endpoint',
     check_str=base.RULE_ADMIN_REQUIRED,
     deprecated_reason=DEPRECATED_REASON,
-    deprecated_since=versionutils.deprecated.TRAIN
+    deprecated_since=versionutils.deprecated.TRAIN,
 )
 
 deprecated_check_policy_assoc_for_service = policy.DeprecatedRule(
     name=base.IDENTITY % 'check_policy_association_for_service',
     check_str=base.RULE_ADMIN_REQUIRED,
     deprecated_reason=DEPRECATED_REASON,
-    deprecated_since=versionutils.deprecated.TRAIN
+    deprecated_since=versionutils.deprecated.TRAIN,
 )
 
 deprecated_check_policy_assoc_for_region_and_service = policy.DeprecatedRule(
     name=base.IDENTITY % 'check_policy_association_for_region_and_service',
     check_str=base.RULE_ADMIN_REQUIRED,
     deprecated_reason=DEPRECATED_REASON,
-    deprecated_since=versionutils.deprecated.TRAIN
+    deprecated_since=versionutils.deprecated.TRAIN,
 )
 
 deprecated_get_policy_for_endpoint = policy.DeprecatedRule(
     name=base.IDENTITY % 'get_policy_for_endpoint',
     check_str=base.RULE_ADMIN_REQUIRED,
     deprecated_reason=DEPRECATED_REASON,
-    deprecated_since=versionutils.deprecated.TRAIN
+    deprecated_since=versionutils.deprecated.TRAIN,
 )
 
 deprecated_list_endpoints_for_policy = policy.DeprecatedRule(
     name=base.IDENTITY % 'list_endpoints_for_policy',
     check_str=base.RULE_ADMIN_REQUIRED,
     deprecated_reason=DEPRECATED_REASON,
-    deprecated_since=versionutils.deprecated.TRAIN
+    deprecated_since=versionutils.deprecated.TRAIN,
 )
 
 deprecated_create_policy_assoc_for_endpoint = policy.DeprecatedRule(
     name=base.IDENTITY % 'create_policy_association_for_endpoint',
     check_str=base.RULE_ADMIN_REQUIRED,
     deprecated_reason=DEPRECATED_REASON,
-    deprecated_since=versionutils.deprecated.TRAIN
+    deprecated_since=versionutils.deprecated.TRAIN,
 )
 
 deprecated_delete_policy_assoc_for_endpoint = policy.DeprecatedRule(
     name=base.IDENTITY % 'delete_policy_association_for_endpoint',
     check_str=base.RULE_ADMIN_REQUIRED,
     deprecated_reason=DEPRECATED_REASON,
-    deprecated_since=versionutils.deprecated.TRAIN
+    deprecated_since=versionutils.deprecated.TRAIN,
 )
 
 deprecated_create_policy_assoc_for_service = policy.DeprecatedRule(
     name=base.IDENTITY % 'create_policy_association_for_service',
     check_str=base.RULE_ADMIN_REQUIRED,
     deprecated_reason=DEPRECATED_REASON,
-    deprecated_since=versionutils.deprecated.TRAIN
+    deprecated_since=versionutils.deprecated.TRAIN,
 )
 
 deprecated_delete_policy_assoc_for_service = policy.DeprecatedRule(
     name=base.IDENTITY % 'delete_policy_association_for_service',
     check_str=base.RULE_ADMIN_REQUIRED,
     deprecated_reason=DEPRECATED_REASON,
-    deprecated_since=versionutils.deprecated.TRAIN
+    deprecated_since=versionutils.deprecated.TRAIN,
 )
 
 deprecated_create_policy_assoc_for_region_and_service = policy.DeprecatedRule(
     name=base.IDENTITY % 'create_policy_association_for_region_and_service',
     check_str=base.RULE_ADMIN_REQUIRED,
     deprecated_reason=DEPRECATED_REASON,
-    deprecated_since=versionutils.deprecated.TRAIN
+    deprecated_since=versionutils.deprecated.TRAIN,
 )
 
 deprecated_delete_policy_assoc_for_region_and_service = policy.DeprecatedRule(
     name=base.IDENTITY % 'delete_policy_association_for_region_and_service',
     check_str=base.RULE_ADMIN_REQUIRED,
     deprecated_reason=DEPRECATED_REASON,
-    deprecated_since=versionutils.deprecated.TRAIN
+    deprecated_since=versionutils.deprecated.TRAIN,
 )
 
 
@@ -108,115 +108,206 @@ policy_association_policies = [
         check_str=base.RULE_ADMIN_REQUIRED,
         scope_types=['system', 'project'],
         description='Associate a policy to a specific endpoint.',
-        operations=[{'path': ('/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
-                              'endpoints/{endpoint_id}'),
-                     'method': 'PUT'}],
-        deprecated_rule=deprecated_create_policy_assoc_for_endpoint),
+        operations=[
+            {
+                'path': (
+                    '/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
+                    'endpoints/{endpoint_id}'
+                ),
+                'method': 'PUT',
+            }
+        ],
+        deprecated_rule=deprecated_create_policy_assoc_for_endpoint,
+    ),
     policy.DocumentedRuleDefault(
         name=base.IDENTITY % 'check_policy_association_for_endpoint',
         check_str=base.RULE_ADMIN_OR_SYSTEM_READER,
         scope_types=['system', 'project'],
         description='Check policy association for endpoint.',
-        operations=[{'path': ('/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
-                              'endpoints/{endpoint_id}'),
-                     'method': 'GET'},
-                    {'path': ('/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
-                              'endpoints/{endpoint_id}'),
-                     'method': 'HEAD'}],
-        deprecated_rule=deprecated_check_policy_assoc_for_endpoint),
+        operations=[
+            {
+                'path': (
+                    '/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
+                    'endpoints/{endpoint_id}'
+                ),
+                'method': 'GET',
+            },
+            {
+                'path': (
+                    '/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
+                    'endpoints/{endpoint_id}'
+                ),
+                'method': 'HEAD',
+            },
+        ],
+        deprecated_rule=deprecated_check_policy_assoc_for_endpoint,
+    ),
     policy.DocumentedRuleDefault(
         name=base.IDENTITY % 'delete_policy_association_for_endpoint',
         check_str=base.RULE_ADMIN_REQUIRED,
         scope_types=['system', 'project'],
         description='Delete policy association for endpoint.',
-        operations=[{'path': ('/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
-                              'endpoints/{endpoint_id}'),
-                     'method': 'DELETE'}],
-        deprecated_rule=deprecated_delete_policy_assoc_for_endpoint),
+        operations=[
+            {
+                'path': (
+                    '/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
+                    'endpoints/{endpoint_id}'
+                ),
+                'method': 'DELETE',
+            }
+        ],
+        deprecated_rule=deprecated_delete_policy_assoc_for_endpoint,
+    ),
     policy.DocumentedRuleDefault(
         name=base.IDENTITY % 'create_policy_association_for_service',
         check_str=base.RULE_ADMIN_REQUIRED,
         scope_types=['system', 'project'],
         description='Associate a policy to a specific service.',
-        operations=[{'path': ('/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
-                              'services/{service_id}'),
-                     'method': 'PUT'}],
-        deprecated_rule=deprecated_create_policy_assoc_for_service),
+        operations=[
+            {
+                'path': (
+                    '/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
+                    'services/{service_id}'
+                ),
+                'method': 'PUT',
+            }
+        ],
+        deprecated_rule=deprecated_create_policy_assoc_for_service,
+    ),
     policy.DocumentedRuleDefault(
         name=base.IDENTITY % 'check_policy_association_for_service',
         check_str=base.RULE_ADMIN_OR_SYSTEM_READER,
         scope_types=['system', 'project'],
         description='Check policy association for service.',
-        operations=[{'path': ('/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
-                              'services/{service_id}'),
-                     'method': 'GET'},
-                    {'path': ('/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
-                              'services/{service_id}'),
-                     'method': 'HEAD'}],
-        deprecated_rule=deprecated_check_policy_assoc_for_service),
+        operations=[
+            {
+                'path': (
+                    '/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
+                    'services/{service_id}'
+                ),
+                'method': 'GET',
+            },
+            {
+                'path': (
+                    '/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
+                    'services/{service_id}'
+                ),
+                'method': 'HEAD',
+            },
+        ],
+        deprecated_rule=deprecated_check_policy_assoc_for_service,
+    ),
     policy.DocumentedRuleDefault(
         name=base.IDENTITY % 'delete_policy_association_for_service',
         check_str=base.RULE_ADMIN_REQUIRED,
         scope_types=['system', 'project'],
         description='Delete policy association for service.',
-        operations=[{'path': ('/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
-                              'services/{service_id}'),
-                     'method': 'DELETE'}],
-        deprecated_rule=deprecated_delete_policy_assoc_for_service),
+        operations=[
+            {
+                'path': (
+                    '/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
+                    'services/{service_id}'
+                ),
+                'method': 'DELETE',
+            }
+        ],
+        deprecated_rule=deprecated_delete_policy_assoc_for_service,
+    ),
     policy.DocumentedRuleDefault(
-        name=base.IDENTITY % (
-            'create_policy_association_for_region_and_service'),
+        name=base.IDENTITY
+        % ('create_policy_association_for_region_and_service'),
         check_str=base.RULE_ADMIN_REQUIRED,
         scope_types=['system', 'project'],
-        description=('Associate a policy to a specific region and service '
-                     'combination.'),
-        operations=[{'path': ('/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
-                              'services/{service_id}/regions/{region_id}'),
-                     'method': 'PUT'}],
-        deprecated_rule=deprecated_create_policy_assoc_for_region_and_service),
+        description=(
+            'Associate a policy to a specific region and service combination.'
+        ),
+        operations=[
+            {
+                'path': (
+                    '/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
+                    'services/{service_id}/regions/{region_id}'
+                ),
+                'method': 'PUT',
+            }
+        ],
+        deprecated_rule=deprecated_create_policy_assoc_for_region_and_service,
+    ),
     policy.DocumentedRuleDefault(
         name=base.IDENTITY % 'check_policy_association_for_region_and_service',
         check_str=base.RULE_ADMIN_OR_SYSTEM_READER,
         scope_types=['system', 'project'],
         description='Check policy association for region and service.',
-        operations=[{'path': ('/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
-                              'services/{service_id}/regions/{region_id}'),
-                     'method': 'GET'},
-                    {'path': ('/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
-                              'services/{service_id}/regions/{region_id}'),
-                     'method': 'HEAD'}],
-        deprecated_rule=deprecated_check_policy_assoc_for_region_and_service),
+        operations=[
+            {
+                'path': (
+                    '/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
+                    'services/{service_id}/regions/{region_id}'
+                ),
+                'method': 'GET',
+            },
+            {
+                'path': (
+                    '/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
+                    'services/{service_id}/regions/{region_id}'
+                ),
+                'method': 'HEAD',
+            },
+        ],
+        deprecated_rule=deprecated_check_policy_assoc_for_region_and_service,
+    ),
     policy.DocumentedRuleDefault(
-        name=base.IDENTITY % (
-            'delete_policy_association_for_region_and_service'),
+        name=base.IDENTITY
+        % ('delete_policy_association_for_region_and_service'),
         check_str=base.RULE_ADMIN_REQUIRED,
         scope_types=['system', 'project'],
         description='Delete policy association for region and service.',
-        operations=[{'path': ('/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
-                              'services/{service_id}/regions/{region_id}'),
-                     'method': 'DELETE'}],
-        deprecated_rule=deprecated_delete_policy_assoc_for_region_and_service),
+        operations=[
+            {
+                'path': (
+                    '/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
+                    'services/{service_id}/regions/{region_id}'
+                ),
+                'method': 'DELETE',
+            }
+        ],
+        deprecated_rule=deprecated_delete_policy_assoc_for_region_and_service,
+    ),
     policy.DocumentedRuleDefault(
         name=base.IDENTITY % 'get_policy_for_endpoint',
         check_str=base.RULE_ADMIN_OR_SYSTEM_READER,
         scope_types=['system', 'project'],
         description='Get policy for endpoint.',
-        operations=[{'path': ('/v3/endpoints/{endpoint_id}/OS-ENDPOINT-POLICY/'
-                              'policy'),
-                     'method': 'GET'},
-                    {'path': ('/v3/endpoints/{endpoint_id}/OS-ENDPOINT-POLICY/'
-                              'policy'),
-                     'method': 'HEAD'}],
-        deprecated_rule=deprecated_get_policy_for_endpoint),
+        operations=[
+            {
+                'path': (
+                    '/v3/endpoints/{endpoint_id}/OS-ENDPOINT-POLICY/policy'
+                ),
+                'method': 'GET',
+            },
+            {
+                'path': (
+                    '/v3/endpoints/{endpoint_id}/OS-ENDPOINT-POLICY/policy'
+                ),
+                'method': 'HEAD',
+            },
+        ],
+        deprecated_rule=deprecated_get_policy_for_endpoint,
+    ),
     policy.DocumentedRuleDefault(
         name=base.IDENTITY % 'list_endpoints_for_policy',
         check_str=base.RULE_ADMIN_OR_SYSTEM_READER,
         scope_types=['system', 'project'],
         description='List endpoints for policy.',
-        operations=[{'path': ('/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/'
-                              'endpoints'),
-                     'method': 'GET'}],
-        deprecated_rule=deprecated_list_endpoints_for_policy)
+        operations=[
+            {
+                'path': (
+                    '/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/endpoints'
+                ),
+                'method': 'GET',
+            }
+        ],
+        deprecated_rule=deprecated_list_endpoints_for_policy,
+    ),
 ]
 
 
