@@ -18,9 +18,9 @@ Before using this module, call initialize(). This has to be done before
 CONF() because it sets up configuration options.
 
 """
+
 import datetime
 import functools
-import pytz
 
 from oslo_db import exception as db_exception
 from oslo_db import options as db_options
@@ -32,8 +32,9 @@ from oslo_utils import timeutils
 from osprofiler import opts as profiler
 import osprofiler.sqlalchemy
 import sqlalchemy as sql
-from sqlalchemy.ext import declarative
-from sqlalchemy.orm.attributes import flag_modified, InstrumentedAttribute
+from sqlalchemy.orm.attributes import flag_modified
+from sqlalchemy.orm.attributes import InstrumentedAttribute
+from sqlalchemy.orm import declarative_base
 from sqlalchemy import types as sql_types
 
 from keystone.common import driver_hints
@@ -42,11 +43,10 @@ import keystone.conf
 from keystone import exception
 from keystone.i18n import _
 
-
 CONF = keystone.conf.CONF
 LOG = log.getLogger(__name__)
 
-ModelBase = declarative.declarative_base()
+ModelBase = declarative_base()
 
 
 # For exporting to other modules
@@ -75,9 +75,7 @@ Unicode = sql.Unicode
 
 def initialize():
     """Initialize the module."""
-    db_options.set_defaults(
-        CONF,
-        connection="sqlite:///keystone.db")
+    db_options.set_defaults(CONF, connection="sqlite:///keystone.db")
     # Configure OSprofiler options
     profiler.set_defaults(CONF, enabled=False, trace_sqlalchemy=False)
 
@@ -94,6 +92,7 @@ def initialize_decorator(init):
     definition.
 
     """
+
     def initialize(self, *args, **kwargs):
         cls = type(self)
         for k, v in kwargs.items():
@@ -106,9 +105,11 @@ def initialize_decorator(init):
                             v = str(v)
                         if column.type.length and column.type.length < len(v):
                             raise exception.StringLengthExceeded(
-                                string=v, type=k, length=column.type.length)
+                                string=v, type=k, length=column.type.length
+                            )
 
         init(self, *args, **kwargs)
+
     return initialize
 
 
@@ -117,7 +118,6 @@ ModelBase.__init__ = initialize_decorator(ModelBase.__init__)
 
 # Special Fields
 class JsonBlob(sql_types.TypeDecorator):
-
     impl = sql.Text
     # NOTE(ralonsoh): set to True as any other TypeDecorator in SQLAlchemy
     # https://docs.sqlalchemy.org/en/14/core/custom_types.html# \
@@ -148,7 +148,7 @@ class DateTimeInt(sql_types.TypeDecorator):
     """
 
     impl = sql.BigInteger
-    epoch = datetime.datetime.fromtimestamp(0, tz=pytz.UTC)
+    epoch = datetime.datetime.fromtimestamp(0, tz=datetime.timezone.utc)
     # NOTE(ralonsoh): set to True as any other TypeDecorator in SQLAlchemy
     # https://docs.sqlalchemy.org/en/14/core/custom_types.html# \
     #   sqlalchemy.types.TypeDecorator.cache_ok
@@ -160,10 +160,14 @@ class DateTimeInt(sql_types.TypeDecorator):
             return value
         else:
             if not isinstance(value, datetime.datetime):
-                raise ValueError(_('Programming Error: value to be stored '
-                                   'must be a datetime object.'))
+                raise ValueError(
+                    _(
+                        'Programming Error: value to be stored '
+                        'must be a datetime object.'
+                    )
+                )
             value = timeutils.normalize_time(value)
-            value = value.replace(tzinfo=pytz.UTC)
+            value = value.replace(tzinfo=datetime.timezone.utc)
             # NOTE(morgan): We are casting this to an int, and ensuring we
             # preserve microsecond data by moving the decimal. This is easier
             # than being concerned with the differences in Numeric types in
@@ -177,9 +181,12 @@ class DateTimeInt(sql_types.TypeDecorator):
             # Convert from INT to appropriate micro-second float (microseconds
             # after the decimal) from what was stored to the DB
             value = float(value) / 1000000
-            # NOTE(morgan): Explictly use timezone "pytz.UTC" to ensure we are
-            # not adjusting the actual datetime object from what we stored.
-            dt_obj = datetime.datetime.fromtimestamp(value, tz=pytz.UTC)
+            # NOTE(morgan): Explictly use timezone "datetime.timezone.utc" to
+            # ensure we are not adjusting the actual datetime object from what
+            # we stored.
+            dt_obj = datetime.datetime.fromtimestamp(
+                value, tz=datetime.timezone.utc
+            )
             # Return non-tz aware datetime object (as keystone expects)
             return timeutils.normalize_time(dt_obj)
 
@@ -193,12 +200,14 @@ class ModelDictMixinWithExtras(models.ModelBase):
           the design philosophy of Keystone.
     """
 
-    attributes = []
-    _msg = ('Programming Error: Model does not have an "extra" column. '
-            'Unless the model already has an "extra" column and has '
-            'existed in a previous released version of keystone with '
-            'the extra column included, the model should use '
-            '"ModelDictMixin" instead.')
+    attributes: list[str] = []
+    _msg = (
+        'Programming Error: Model does not have an "extra" column. '
+        'Unless the model already has an "extra" column and has '
+        'existed in a previous released version of keystone with '
+        'the extra column included, the model should use '
+        '"ModelDictMixin" instead.'
+    )
 
     @classmethod
     def from_dict(cls, d):
@@ -209,8 +218,11 @@ class ModelDictMixinWithExtras(models.ModelBase):
             # programmers NOT end users.
             raise AttributeError(cls._msg)  # no qa
 
-        new_d['extra'] = {k: new_d.pop(k) for k in d.keys()
-                          if k not in cls.attributes and k != 'extra'}
+        new_d['extra'] = {
+            k: new_d.pop(k)
+            for k in d.keys()
+            if k not in cls.attributes and k != 'extra'
+        }
 
         return cls(**new_d)
 
@@ -244,7 +256,6 @@ class ModelDictMixinWithExtras(models.ModelBase):
 
 
 class ModelDictMixin(models.ModelBase):
-
     @classmethod
     def from_dict(cls, d):
         """Return a model instance from a dictionary."""
@@ -291,6 +302,7 @@ def _get_context():
         # NOTE(dims): Delay the `threading.local` import to allow for
         # eventlet/gevent monkeypatching to happen
         import threading
+
         _CONTEXT = threading.local()
     return _CONTEXT
 
@@ -374,6 +386,7 @@ def _filter(model, query, hints):
     :returns: query updated with any filters satisfied
 
     """
+
     def inexact_filter(model, query, filter_, satisfied_filters):
         """Apply an inexact filter to a query.
 
@@ -399,13 +412,13 @@ def _filter(model, query, hints):
 
         if filter_['comparator'] == 'contains':
             _WontMatch.check(filter_['value'], column_attr)
-            query_term = column_attr.ilike('%%%s%%' % filter_['value'])
+            query_term = column_attr.ilike('%{}%'.format(filter_['value']))
         elif filter_['comparator'] == 'startswith':
             _WontMatch.check(filter_['value'], column_attr)
-            query_term = column_attr.ilike('%s%%' % filter_['value'])
+            query_term = column_attr.ilike('{}%'.format(filter_['value']))
         elif filter_['comparator'] == 'endswith':
             _WontMatch.check(filter_['value'], column_attr)
-            query_term = column_attr.ilike('%%%s' % filter_['value'])
+            query_term = column_attr.ilike('%{}'.format(filter_['value']))
         else:
             # It's a filter we don't understand, so let the caller
             # work out if they need to do something with it.
@@ -442,11 +455,11 @@ def _filter(model, query, hints):
             if filter_['name'] not in model.attributes:
                 continue
             if filter_['comparator'] == 'equals':
-                query = exact_filter(model, query, filter_,
-                                     satisfied_filters)
+                query = exact_filter(model, query, filter_, satisfied_filters)
             else:
-                query = inexact_filter(model, query, filter_,
-                                       satisfied_filters)
+                query = inexact_filter(
+                    model, query, filter_, satisfied_filters
+                )
 
         # Remove satisfied filters, then the caller will know remaining filters
         for filter_ in satisfied_filters:
@@ -480,6 +493,40 @@ def _limit(query, hints):
     return query
 
 
+def filter_query(model, query, hints):
+    """Apply filtering to a query.
+
+    :param model: table model
+    :param query: query to apply filters to
+    :param hints: contains the list of filters and limit details.  This may
+                  be None, indicating that there are no filters or limits
+                  to be applied. If it's not None, then any filters
+                  satisfied here will be removed so that the caller will
+                  know if any filters remain.
+
+    :returns: query updated with any filters and limits satisfied
+
+    """
+    if hints is None:
+        return query
+
+    # First try and satisfy any filters
+    query = _filter(model, query, hints)
+
+    if hints.cannot_match:
+        # Nothing's going to match, so don't bother with the query.
+        return []
+
+    # NOTE(henry-nash): Any unsatisfied filters will have been left in
+    # the hints list for the controller to handle. We can only try and
+    # limit here if all the filters are already satisfied since, if not,
+    # doing so might mess up the final results. If there are still
+    # unsatisfied filters, we have to leave any limiting to the controller
+    # as well.
+
+    return query
+
+
 def filter_limit_query(model, query, hints):
     """Apply filtering and limit to a query.
 
@@ -530,8 +577,10 @@ def handle_conflicts(conflict_type='object'):
                 # LOG the exception for debug purposes, do not send the
                 # exception details out with the raised Conflict exception
                 # as it can contain raw SQL.
-                LOG.debug(_conflict_msg, {'conflict_type': conflict_type,
-                                          'details': e})
+                LOG.debug(
+                    _conflict_msg,
+                    {'conflict_type': conflict_type, 'details': e},
+                )
                 name = None
                 field = None
                 domain_id = None
@@ -552,16 +601,17 @@ def handle_conflicts(conflict_type='object'):
                             domain_id = arg['domain_id']
                 msg = _('Duplicate entry')
                 if name and domain_id:
-                    msg = _('Duplicate entry found with %(field)s %(name)s '
-                            'at domain ID %(domain_id)s') % {
-                        'field': field, 'name': name, 'domain_id': domain_id}
+                    msg = _(
+                        'Duplicate entry found with %(field)s %(name)s '
+                        'at domain ID %(domain_id)s'
+                    ) % {'field': field, 'name': name, 'domain_id': domain_id}
                 elif name:
-                    msg = _('Duplicate entry found with %(field)s '
-                            '%(name)s') % {'field': field, 'name': name}
+                    msg = _(
+                        'Duplicate entry found with %(field)s %(name)s'
+                    ) % {'field': field, 'name': name}
                 elif domain_id:
-                    msg = (_('Duplicate entry at domain ID %s') % domain_id)
-                raise exception.Conflict(type=conflict_type,
-                                         details=msg)
+                    msg = _('Duplicate entry at domain ID %s') % domain_id
+                raise exception.Conflict(type=conflict_type, details=msg)
             except db_exception.DBError as e:
                 # TODO(blk-u): inspecting inner_exception breaks encapsulation;
                 # oslo_db should provide exception we need.
@@ -569,17 +619,24 @@ def handle_conflicts(conflict_type='object'):
                     # LOG the exception for debug purposes, do not send the
                     # exception details out with the raised Conflict exception
                     # as it can contain raw SQL.
-                    LOG.debug(_conflict_msg, {'conflict_type': conflict_type,
-                                              'details': e})
+                    LOG.debug(
+                        _conflict_msg,
+                        {'conflict_type': conflict_type, 'details': e},
+                    )
                     # NOTE(morganfainberg): This is really a case where the SQL
                     # failed to store the data. This is not something that the
                     # user has done wrong. Example would be a ForeignKey is
                     # missing; the code that is executed before reaching the
                     # SQL writing to the DB should catch the issue.
                     raise exception.UnexpectedError(
-                        _('An unexpected error occurred when trying to '
-                          'store %s') % conflict_type)
+                        _(
+                            'An unexpected error occurred when trying to '
+                            'store %s'
+                        )
+                        % conflict_type
+                    )
                 raise
 
         return wrapper
+
     return decorator
