@@ -328,7 +328,7 @@ class InsufficientAuthMethods(Error):
     title = 'Unauthorized'
 
     def __init__(self, message=None, user_id=None, methods=None):
-        methods_str = '[%s]' % ','.join(methods)
+        methods_str = '[{}]'.format(','.join(methods))
         super().__init__(message, user_id=user_id, methods=methods_str)
 
         self.user_id = user_id
@@ -394,8 +394,7 @@ class Forbidden(SecurityError):
 
 class ForbiddenAction(Forbidden):
     message_format = _(
-        "You are not authorized to perform the"
-        " requested action: %(action)s."
+        "You are not authorized to perform the requested action: %(action)s."
     )
 
 
@@ -443,6 +442,10 @@ class NotFound(Error):
     title = http.client.responses[http.client.NOT_FOUND]
 
 
+class MarkerNotFound(NotFound):
+    message_format = _("Marker %(marker)s could not be found.")
+
+
 class EndpointNotFound(NotFound):
     message_format = _("Could not find endpoint: %(endpoint_id)s.")
 
@@ -580,8 +583,7 @@ class LimitNotFound(NotFound):
 
 class NoLimitReference(Forbidden):
     message_format = _(
-        "Unable to create a limit that has no corresponding "
-        "registered limit."
+        "Unable to create a limit that has no corresponding registered limit."
     )
 
 
@@ -608,8 +610,7 @@ class ConfigRegistrationNotFound(Exception):
 
 class ApplicationCredentialNotFound(NotFound):
     message_format = _(
-        "Could not find Application Credential: "
-        "%(application_credential_id)s."
+        "Could not find Application Credential: %(application_credential_id)s."
     )
 
 
@@ -639,7 +640,6 @@ class UnexpectedError(SecurityError):
     )
 
     def _build_message(self, message, **kwargs):
-
         # Ensure that exception has a value to be extra defensive for
         # substitutions and make sure the exception doesn't raise an
         # exception.
@@ -702,8 +702,7 @@ class NotImplemented(Error):
 
 class Gone(Error):
     message_format = _(
-        "The service you have requested is no"
-        " longer available on this server."
+        "The service you have requested is no longer available on this server."
     )
     code = int(http.client.GONE)
     title = http.client.responses[http.client.GONE]
@@ -711,8 +710,7 @@ class Gone(Error):
 
 class ConfigFileNotFound(UnexpectedError):
     debug_message_format = _(
-        "The Keystone configuration file %(config_file)s "
-        "could not be found."
+        "The Keystone configuration file %(config_file)s could not be found."
     )
 
 
@@ -801,7 +799,6 @@ class LDAPSizeLimitExceeded(UnexpectedError):
 
 
 class CacheDeserializationError(Exception):
-
     def __init__(self, obj, data):
         super().__init__(
             _('Failed to deserialize %(obj)s. Data is %(data)s')
@@ -826,7 +823,6 @@ class ResourceDeleteForbidden(ForbiddenNotSecurity):
 
 
 class OAuth2Error(Error):
-
     def __init__(self, code, title, error_title, message):
         self.code = code
         self.title = title
