@@ -135,7 +135,7 @@ class Identity(base.IdentityDriverBase):
                     ' not found in the directory. The user should be'
                     ' removed from the group. The user will be ignored.'
                 )
-                LOG.debug(msg, dict(user_id=user_id, group_id=group_id))
+                LOG.debug(msg, {'user_id': user_id, 'group_id': group_id})
         return users
 
     def check_user_in_group(self, user_id, group_id):
@@ -413,11 +413,7 @@ class GroupApi(common_ldap.BaseLdap):
         """Return a list of groups for which the user is a member."""
         user_dn_esc = ldap.filter.escape_filter_chars(user_dn)
         if self.group_ad_nesting:
-            query = '({}:{}:={})'.format(
-                self.member_attribute,
-                LDAP_MATCHING_RULE_IN_CHAIN,
-                user_dn_esc,
-            )
+            query = f'({self.member_attribute}:{LDAP_MATCHING_RULE_IN_CHAIN}:={user_dn_esc})'
         else:
             query = f'({self.member_attribute}={user_dn_esc})'
         return self.get_all(query)
@@ -429,10 +425,7 @@ class GroupApi(common_ldap.BaseLdap):
             # Hardcoded to member as that is how the Matching Rule in Chain
             # Mechanisms expects it.  The member_attribute might actually be
             # member_of elsewhere, so they are not the same.
-            query = '(member:{}:={})'.format(
-                LDAP_MATCHING_RULE_IN_CHAIN,
-                user_dn_esc,
-            )
+            query = f'(member:{LDAP_MATCHING_RULE_IN_CHAIN}:={user_dn_esc})'
         else:
             query = f'({self.member_attribute}={user_dn_esc})'
         return self.get_all_filtered(hints, query)
@@ -441,23 +434,26 @@ class GroupApi(common_ldap.BaseLdap):
         """Return a list of user dns which are members of a group."""
         group_ref = self.get(group_id)
         group_dn = group_ref['dn']
+        attribute = self.member_attribute
 
         try:
             if self.group_ad_nesting:
                 # NOTE(ayoung): LDAP_SCOPE is used here instead of hard-
                 # coding to SCOPE_SUBTREE to get through the unit tests.
                 # However, it is also probably more correct.
+                attribute = "distinguishedName"
                 attrs = self._ldap_get_list(
-                    self.tree_dn,
+                    self.user_tree_dn,
                     self.LDAP_SCOPE,
                     query_params={
-                        "member:%s:" % LDAP_MATCHING_RULE_IN_CHAIN: group_dn
+                        f"memberOf:{LDAP_MATCHING_RULE_IN_CHAIN}:": group_dn
                     },
-                    attrlist=[self.member_attribute],
+                    attrlist=[attribute],
+                    object_class=self.user_objectclass,
                 )
             else:
                 attrs = self._ldap_get_list(
-                    group_dn, ldap.SCOPE_BASE, attrlist=[self.member_attribute]
+                    group_dn, ldap.SCOPE_BASE, attrlist=[attribute]
                 )
 
         except ldap.NO_SUCH_OBJECT:
@@ -465,7 +461,7 @@ class GroupApi(common_ldap.BaseLdap):
 
         users = []
         for dn, member in attrs:
-            user_dns = member.get(self.member_attribute, [])
+            user_dns = member.get(attribute, [])
             for user_dn in user_dns:
                 users.append(user_dn)
         return users
