@@ -45,8 +45,9 @@ class _SystemUserPoliciesAssociationTests:
 
         with self.test_client() as c:
             c.get(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints/%s'
-                % (policy['id'], endpoint['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/endpoints/{}'.format(
+                    policy['id'], endpoint['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.NO_CONTENT,
             )
@@ -65,8 +66,9 @@ class _SystemUserPoliciesAssociationTests:
 
         with self.test_client() as c:
             c.get(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s'
-                % (policy['id'], service['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/services/{}'.format(
+                    policy['id'], service['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.NO_CONTENT,
             )
@@ -87,8 +89,9 @@ class _SystemUserPoliciesAssociationTests:
 
         with self.test_client() as c:
             c.get(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s/regions/%s'
-                % (policy['id'], service['id'], region['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/services/{}/regions/{}'.format(
+                    policy['id'], service['id'], region['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.NO_CONTENT,
             )
@@ -108,8 +111,9 @@ class _SystemUserPoliciesAssociationTests:
         )
         with self.test_client() as c:
             c.get(
-                '/v3/endpoints/%s/OS-ENDPOINT-POLICY/policy'
-                % (endpoint['id']),
+                '/v3/endpoints/{}/OS-ENDPOINT-POLICY/policy'.format(
+                    endpoint['id']
+                ),
                 headers=self.headers,
             )
 
@@ -128,8 +132,9 @@ class _SystemUserPoliciesAssociationTests:
         )
         with self.test_client() as c:
             r = c.get(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints'
-                % (policy['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/endpoints'.format(
+                    policy['id']
+                ),
                 headers=self.headers,
             )
             for endpoint_itr in r.json['endpoints']:
@@ -137,7 +142,6 @@ class _SystemUserPoliciesAssociationTests:
 
 
 class _SystemReaderAndMemberPoliciesAssociationTests:
-
     def test_user_cannot_create_policy_association_for_endpoint(self):
         policy = unit.new_policy_ref()
         policy = PROVIDERS.policy_api.create_policy(policy['id'], policy)
@@ -151,8 +155,9 @@ class _SystemReaderAndMemberPoliciesAssociationTests:
 
         with self.test_client() as c:
             c.put(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints/%s'
-                % (policy['id'], endpoint['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/endpoints/{}'.format(
+                    policy['id'], endpoint['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.FORBIDDEN,
             )
@@ -170,8 +175,9 @@ class _SystemReaderAndMemberPoliciesAssociationTests:
 
         with self.test_client() as c:
             c.delete(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints/%s'
-                % (policy['id'], endpoint['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/endpoints/{}'.format(
+                    policy['id'], endpoint['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.FORBIDDEN,
             )
@@ -184,8 +190,9 @@ class _SystemReaderAndMemberPoliciesAssociationTests:
         )
         with self.test_client() as c:
             c.put(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s'
-                % (policy['id'], service['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/services/{}'.format(
+                    policy['id'], service['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.FORBIDDEN,
             )
@@ -199,8 +206,9 @@ class _SystemReaderAndMemberPoliciesAssociationTests:
 
         with self.test_client() as c:
             c.delete(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s'
-                % (policy['id'], service['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/services/{}'.format(
+                    policy['id'], service['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.FORBIDDEN,
             )
@@ -215,8 +223,9 @@ class _SystemReaderAndMemberPoliciesAssociationTests:
 
         with self.test_client() as c:
             c.put(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s/regions/%s'
-                % (policy['id'], service['id'], region['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/services/{}/regions/{}'.format(
+                    policy['id'], service['id'], region['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.FORBIDDEN,
             )
@@ -231,15 +240,15 @@ class _SystemReaderAndMemberPoliciesAssociationTests:
 
         with self.test_client() as c:
             c.delete(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s/regions/%s'
-                % (policy['id'], service['id'], region['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/services/{}/regions/{}'.format(
+                    policy['id'], service['id'], region['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.FORBIDDEN,
             )
 
 
 class _DomainAndProjectUserPolicyAssociationsTests:
-
     def test_user_cannot_check_policy_association_for_endpoint(self):
         policy = unit.new_policy_ref()
         policy = PROVIDERS.policy_api.create_policy(policy['id'], policy)
@@ -258,8 +267,9 @@ class _DomainAndProjectUserPolicyAssociationsTests:
 
         with self.test_client() as c:
             c.get(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints/%s'
-                % (policy['id'], endpoint['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/endpoints/{}'.format(
+                    policy['id'], endpoint['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.FORBIDDEN,
             )
@@ -278,8 +288,9 @@ class _DomainAndProjectUserPolicyAssociationsTests:
 
         with self.test_client() as c:
             c.get(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s'
-                % (policy['id'], service['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/services/{}'.format(
+                    policy['id'], service['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.FORBIDDEN,
             )
@@ -300,8 +311,9 @@ class _DomainAndProjectUserPolicyAssociationsTests:
 
         with self.test_client() as c:
             c.get(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s/regions/%s'
-                % (policy['id'], service['id'], region['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/services/{}/regions/{}'.format(
+                    policy['id'], service['id'], region['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.FORBIDDEN,
             )
@@ -321,8 +333,9 @@ class _DomainAndProjectUserPolicyAssociationsTests:
         )
         with self.test_client() as c:
             c.get(
-                '/v3/endpoints/%s/OS-ENDPOINT-POLICY/policy'
-                % (endpoint['id']),
+                '/v3/endpoints/{}/OS-ENDPOINT-POLICY/policy'.format(
+                    endpoint['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.FORBIDDEN,
             )
@@ -342,8 +355,9 @@ class _DomainAndProjectUserPolicyAssociationsTests:
         )
         with self.test_client() as c:
             c.get(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints'
-                % (policy['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/endpoints'.format(
+                    policy['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.FORBIDDEN,
             )
@@ -361,8 +375,9 @@ class _DomainAndProjectUserPolicyAssociationsTests:
 
         with self.test_client() as c:
             c.put(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints/%s'
-                % (policy['id'], endpoint['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/endpoints/{}'.format(
+                    policy['id'], endpoint['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.FORBIDDEN,
             )
@@ -380,8 +395,9 @@ class _DomainAndProjectUserPolicyAssociationsTests:
 
         with self.test_client() as c:
             c.delete(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints/%s'
-                % (policy['id'], endpoint['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/endpoints/{}'.format(
+                    policy['id'], endpoint['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.FORBIDDEN,
             )
@@ -394,8 +410,9 @@ class _DomainAndProjectUserPolicyAssociationsTests:
         )
         with self.test_client() as c:
             c.put(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s'
-                % (policy['id'], service['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/services/{}'.format(
+                    policy['id'], service['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.FORBIDDEN,
             )
@@ -409,8 +426,9 @@ class _DomainAndProjectUserPolicyAssociationsTests:
 
         with self.test_client() as c:
             c.delete(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s'
-                % (policy['id'], service['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/services/{}'.format(
+                    policy['id'], service['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.FORBIDDEN,
             )
@@ -425,8 +443,9 @@ class _DomainAndProjectUserPolicyAssociationsTests:
 
         with self.test_client() as c:
             c.put(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s/regions/%s'
-                % (policy['id'], service['id'], region['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/services/{}/regions/{}'.format(
+                    policy['id'], service['id'], region['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.FORBIDDEN,
             )
@@ -441,8 +460,9 @@ class _DomainAndProjectUserPolicyAssociationsTests:
 
         with self.test_client() as c:
             c.delete(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s/regions/%s'
-                % (policy['id'], service['id'], region['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/services/{}/regions/{}'.format(
+                    policy['id'], service['id'], region['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.FORBIDDEN,
             )
@@ -454,7 +474,6 @@ class SystemReaderTests(
     _SystemUserPoliciesAssociationTests,
     _SystemReaderAndMemberPoliciesAssociationTests,
 ):
-
     def setUp(self):
         super().setUp()
         self.loadapp()
@@ -489,7 +508,6 @@ class SystemMemberTests(
     _SystemUserPoliciesAssociationTests,
     _SystemReaderAndMemberPoliciesAssociationTests,
 ):
-
     def setUp(self):
         super().setUp()
         self.loadapp()
@@ -523,7 +541,6 @@ class SystemAdminTests(
     common_auth.AuthTestMixin,
     _SystemUserPoliciesAssociationTests,
 ):
-
     def setUp(self):
         super().setUp()
         self.loadapp()
@@ -559,8 +576,9 @@ class SystemAdminTests(
 
         with self.test_client() as c:
             c.put(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints/%s'
-                % (policy['id'], endpoint['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/endpoints/{}'.format(
+                    policy['id'], endpoint['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.NO_CONTENT,
             )
@@ -578,8 +596,9 @@ class SystemAdminTests(
 
         with self.test_client() as c:
             c.delete(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints/%s'
-                % (policy['id'], endpoint['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/endpoints/{}'.format(
+                    policy['id'], endpoint['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.NO_CONTENT,
             )
@@ -592,8 +611,9 @@ class SystemAdminTests(
         )
         with self.test_client() as c:
             c.put(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s'
-                % (policy['id'], service['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/services/{}'.format(
+                    policy['id'], service['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.NO_CONTENT,
             )
@@ -607,8 +627,9 @@ class SystemAdminTests(
 
         with self.test_client() as c:
             c.delete(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s'
-                % (policy['id'], service['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/services/{}'.format(
+                    policy['id'], service['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.NO_CONTENT,
             )
@@ -623,8 +644,9 @@ class SystemAdminTests(
 
         with self.test_client() as c:
             c.put(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s/regions/%s'
-                % (policy['id'], service['id'], region['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/services/{}/regions/{}'.format(
+                    policy['id'], service['id'], region['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.NO_CONTENT,
             )
@@ -639,8 +661,9 @@ class SystemAdminTests(
 
         with self.test_client() as c:
             c.delete(
-                '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s/regions/%s'
-                % (policy['id'], service['id'], region['id']),
+                '/v3/policies/{}/OS-ENDPOINT-POLICY/services/{}/regions/{}'.format(
+                    policy['id'], service['id'], region['id']
+                ),
                 headers=self.headers,
                 expected_status_code=http.client.NO_CONTENT,
             )
@@ -651,7 +674,6 @@ class DomainUserTests(
     common_auth.AuthTestMixin,
     _DomainAndProjectUserPolicyAssociationsTests,
 ):
-
     def setUp(self):
         super().setUp()
         self.loadapp()
@@ -689,7 +711,6 @@ class ProjectUserTests(
     common_auth.AuthTestMixin,
     _DomainAndProjectUserPolicyAssociationsTests,
 ):
-
     def setUp(self):
         super().setUp()
         self.loadapp()
@@ -716,7 +737,6 @@ class ProjectUserTestsWithoutEnforceScope(
     common_auth.AuthTestMixin,
     _DomainAndProjectUserPolicyAssociationsTests,
 ):
-
     def setUp(self):
         super().setUp()
         self.loadapp()
