@@ -11,12 +11,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from keystone.tests.unit.ksfixtures.auth_plugins import (
-    ConfigAuthPlugins,
-)  # noqa
-from keystone.tests.unit.ksfixtures.jws_key_repository import (
-    JWSKeyRepository,
-)  # noqa
+from keystone.tests.unit.ksfixtures.auth_plugins import ConfigAuthPlugins  # noqa
+from keystone.tests.unit.ksfixtures.jws_key_repository import JWSKeyRepository  # noqa
 
 from keystone.tests.unit.ksfixtures.backendloader import BackendLoader  # noqa
 from keystone.tests.unit.ksfixtures.cache import Cache  # noqa
