@@ -30,9 +30,7 @@ class WarningsFixture(fixtures.Fixture):
         warnings.simplefilter('once', DeprecationWarning)
 
         warnings.filterwarnings(
-            'error',
-            module='keystone',
-            category=DeprecationWarning,
+            'error', module='keystone', category=DeprecationWarning
         )
 
         warnings.filterwarnings(
@@ -52,31 +50,19 @@ class WarningsFixture(fixtures.Fixture):
             category=UserWarning,
         )
 
-        # TODO(stephenfin): This will be fixed once we drop sqlalchemy-migrate
         warnings.filterwarnings(
-            'ignore',
-            category=DeprecationWarning,
-            message=r"Using function/method 'db_version\(\)' is deprecated",
+            'error', module='keystone', category=sqla_exc.SAWarning
         )
 
         warnings.filterwarnings(
-            'error',
-            module='keystone',
-            category=sqla_exc.SAWarning,
-        )
-
-        warnings.filterwarnings(
-            'ignore',
-            category=sqla_exc.SADeprecationWarning,
+            'ignore', category=sqla_exc.SADeprecationWarning
         )
 
         # Enable deprecation warnings for keystone itself to capture upcoming
         # SQLALchemy changes
 
         warnings.filterwarnings(
-            'error',
-            module='keystone',
-            category=sqla_exc.SADeprecationWarning,
+            'error', module='keystone', category=sqla_exc.SADeprecationWarning
         )
 
         self.addCleanup(self._reset_warning_filters)
