@@ -13,9 +13,9 @@
 # under the License.
 
 import datetime
+import urllib
 
 from oslo_utils import timeutils
-from six.moves import urllib
 
 from keystone.common import provider_api
 from keystone.common import utils
@@ -28,7 +28,6 @@ from keystone.tests.unit.ksfixtures import database
 from keystone import token
 from keystone.token import provider
 
-
 CONF = keystone.conf.CONF
 PROVIDERS = provider_api.ProviderAPIs
 
@@ -38,13 +37,13 @@ CURRENT_DATE = timeutils.utcnow()
 
 class TestTokenProvider(unit.TestCase):
     def setUp(self):
-        super(TestTokenProvider, self).setUp()
+        super().setUp()
         self.useFixture(database.Database())
         self.useFixture(
             ksfixtures.KeyRepository(
                 self.config_fixture,
                 'fernet_tokens',
-                CONF.fernet_tokens.max_active_keys
+                CONF.fernet_tokens.max_active_keys,
             )
         )
         self.load_backends()
@@ -54,19 +53,19 @@ class TestTokenProvider(unit.TestCase):
         self.assertEqual(s, urllib.parse.quote_plus(s))
 
     def test_unsupported_token_provider(self):
-        self.config_fixture.config(group='token',
-                                   provider='MyProvider')
-        self.assertRaises(ImportError,
-                          token.provider.Manager)
+        self.config_fixture.config(group='token', provider='MyProvider')
+        self.assertRaises(ImportError, token.provider.Manager)
 
     def test_provider_token_expiration_validation(self):
         token = token_model.TokenModel()
         token.issued_at = "2013-05-21T00:02:43.941473Z"
         token.expires_at = utils.isotime(CURRENT_DATE)
 
-        self.assertRaises(exception.TokenNotFound,
-                          PROVIDERS.token_provider_api._is_valid_token,
-                          token)
+        self.assertRaises(
+            exception.TokenNotFound,
+            PROVIDERS.token_provider_api._is_valid_token,
+            token,
+        )
 
         token = token_model.TokenModel()
         token.issued_at = "2013-05-21T00:02:43.941473Z"
@@ -77,4 +76,5 @@ class TestTokenProvider(unit.TestCase):
         self.assertRaises(
             exception.TokenNotFound,
             PROVIDERS.token_provider_api.validate_token,
-            None)
+            None,
+        )
