@@ -82,54 +82,49 @@ class EndpointPolicyTestCase(test_v3.RestfulTestCase):
     def test_crud_for_policy_for_explicit_endpoint(self):
         """PUT, HEAD and DELETE for explicit endpoint policy."""
         url = (
-            '/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
-            '/endpoints/%(endpoint_id)s'
-        ) % {
-            'policy_id': self.policy['id'],
-            'endpoint_id': self.endpoint['id'],
-        }
+            '/policies/{policy_id}/OS-ENDPOINT-POLICY/endpoints/{endpoint_id}'
+        ).format(policy_id=self.policy['id'], endpoint_id=self.endpoint['id'])
         self._crud_test(url)
 
     def test_crud_for_policy_for_service(self):
         """PUT, HEAD and DELETE for service endpoint policy."""
         url = (
-            '/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
-            '/services/%(service_id)s'
-        ) % {'policy_id': self.policy['id'], 'service_id': self.service['id']}
+            '/policies/{policy_id}/OS-ENDPOINT-POLICY/services/{service_id}'
+        ).format(policy_id=self.policy['id'], service_id=self.service['id'])
         self._crud_test(url)
 
     def test_crud_for_policy_for_region_and_service(self):
         """PUT, HEAD and DELETE for region and service endpoint policy."""
         url = (
-            '/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
-            '/services/%(service_id)s/regions/%(region_id)s'
-        ) % {
-            'policy_id': self.policy['id'],
-            'service_id': self.service['id'],
-            'region_id': self.region['id'],
-        }
+            '/policies/{policy_id}/OS-ENDPOINT-POLICY'
+            '/services/{service_id}/regions/{region_id}'
+        ).format(
+            policy_id=self.policy['id'],
+            service_id=self.service['id'],
+            region_id=self.region['id'],
+        )
         self._crud_test(url)
 
     def test_get_policy_for_endpoint(self):
         """GET /endpoints/{endpoint_id}/policy."""
         self.put(
-            '/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
-            '/endpoints/%(endpoint_id)s'
-            % {
-                'policy_id': self.policy['id'],
-                'endpoint_id': self.endpoint['id'],
-            }
+            '/policies/{policy_id}/OS-ENDPOINT-POLICY'
+            '/endpoints/{endpoint_id}'.format(
+                policy_id=self.policy['id'], endpoint_id=self.endpoint['id']
+            )
         )
 
         self.head(
-            '/endpoints/%(endpoint_id)s/OS-ENDPOINT-POLICY'
-            '/policy' % {'endpoint_id': self.endpoint['id']},
+            '/endpoints/{endpoint_id}/OS-ENDPOINT-POLICY/policy'.format(
+                endpoint_id=self.endpoint['id']
+            ),
             expected_status=http.client.OK,
         )
 
         r = self.get(
-            '/endpoints/%(endpoint_id)s/OS-ENDPOINT-POLICY'
-            '/policy' % {'endpoint_id': self.endpoint['id']}
+            '/endpoints/{endpoint_id}/OS-ENDPOINT-POLICY/policy'.format(
+                endpoint_id=self.endpoint['id']
+            )
         )
         self.assertValidPolicyResponse(r, ref=self.policy)
 
@@ -146,12 +141,8 @@ class EndpointPolicyTestCase(test_v3.RestfulTestCase):
 
     def test_endpoint_association_cleanup_when_endpoint_deleted(self):
         url = (
-            '/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
-            '/endpoints/%(endpoint_id)s'
-        ) % {
-            'policy_id': self.policy['id'],
-            'endpoint_id': self.endpoint['id'],
-        }
+            '/policies/{policy_id}/OS-ENDPOINT-POLICY/endpoints/{endpoint_id}'
+        ).format(policy_id=self.policy['id'], endpoint_id=self.endpoint['id'])
 
         self.put(url)
         self.head(url)
@@ -164,13 +155,13 @@ class EndpointPolicyTestCase(test_v3.RestfulTestCase):
 
     def test_region_service_association_cleanup_when_region_deleted(self):
         url = (
-            '/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
-            '/services/%(service_id)s/regions/%(region_id)s'
-        ) % {
-            'policy_id': self.policy['id'],
-            'service_id': self.service['id'],
-            'region_id': self.region['id'],
-        }
+            '/policies/{policy_id}/OS-ENDPOINT-POLICY'
+            '/services/{service_id}/regions/{region_id}'
+        ).format(
+            policy_id=self.policy['id'],
+            service_id=self.service['id'],
+            region_id=self.region['id'],
+        )
 
         self.put(url)
         self.head(url)
@@ -181,13 +172,13 @@ class EndpointPolicyTestCase(test_v3.RestfulTestCase):
 
     def test_region_service_association_cleanup_when_service_deleted(self):
         url = (
-            '/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
-            '/services/%(service_id)s/regions/%(region_id)s'
-        ) % {
-            'policy_id': self.policy['id'],
-            'service_id': self.service['id'],
-            'region_id': self.region['id'],
-        }
+            '/policies/{policy_id}/OS-ENDPOINT-POLICY'
+            '/services/{service_id}/regions/{region_id}'
+        ).format(
+            policy_id=self.policy['id'],
+            service_id=self.service['id'],
+            region_id=self.region['id'],
+        )
 
         self.put(url)
         self.head(url)
@@ -200,9 +191,8 @@ class EndpointPolicyTestCase(test_v3.RestfulTestCase):
 
     def test_service_association_cleanup_when_service_deleted(self):
         url = (
-            '/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
-            '/services/%(service_id)s'
-        ) % {'policy_id': self.policy['id'], 'service_id': self.service['id']}
+            '/policies/{policy_id}/OS-ENDPOINT-POLICY/services/{service_id}'
+        ).format(policy_id=self.policy['id'], service_id=self.service['id'])
 
         self.put(url)
         self.get(url, expected_status=http.client.NO_CONTENT)
@@ -215,9 +205,8 @@ class EndpointPolicyTestCase(test_v3.RestfulTestCase):
 
     def test_service_association_cleanup_when_policy_deleted(self):
         url = (
-            '/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
-            '/services/%(service_id)s'
-        ) % {'policy_id': self.policy['id'], 'service_id': self.service['id']}
+            '/policies/{policy_id}/OS-ENDPOINT-POLICY/services/{service_id}'
+        ).format(policy_id=self.policy['id'], service_id=self.service['id'])
 
         self.put(url)
         self.get(url, expected_status=http.client.NO_CONTENT)
@@ -239,24 +228,17 @@ class JsonHomeTests(test_v3.JsonHomeTestMixin):
     )
 
     JSON_HOME_DATA = {
-        EXTENSION_LOCATION
-        + '/endpoint_policy': {
+        EXTENSION_LOCATION + '/endpoint_policy': {
             'href-template': '/endpoints/{endpoint_id}/OS-ENDPOINT-POLICY/'
             'policy',
-            'href-vars': {
-                'endpoint_id': PARAM_LOCATION + '/endpoint_id',
-            },
+            'href-vars': {'endpoint_id': PARAM_LOCATION + '/endpoint_id'},
         },
-        EXTENSION_LOCATION
-        + '/policy_endpoints': {
+        EXTENSION_LOCATION + '/policy_endpoints': {
             'href-template': '/policies/{policy_id}/OS-ENDPOINT-POLICY/'
             'endpoints',
-            'href-vars': {
-                'policy_id': PARAM_LOCATION + '/policy_id',
-            },
+            'href-vars': {'policy_id': PARAM_LOCATION + '/policy_id'},
         },
-        EXTENSION_LOCATION
-        + '/endpoint_policy_association': {
+        EXTENSION_LOCATION + '/endpoint_policy_association': {
             'href-template': '/policies/{policy_id}/OS-ENDPOINT-POLICY/'
             'endpoints/{endpoint_id}',
             'href-vars': {
@@ -264,8 +246,7 @@ class JsonHomeTests(test_v3.JsonHomeTestMixin):
                 'endpoint_id': PARAM_LOCATION + '/endpoint_id',
             },
         },
-        EXTENSION_LOCATION
-        + '/service_policy_association': {
+        EXTENSION_LOCATION + '/service_policy_association': {
             'href-template': '/policies/{policy_id}/OS-ENDPOINT-POLICY/'
             'services/{service_id}',
             'href-vars': {
@@ -273,8 +254,7 @@ class JsonHomeTests(test_v3.JsonHomeTestMixin):
                 'service_id': PARAM_LOCATION + '/service_id',
             },
         },
-        EXTENSION_LOCATION
-        + '/region_and_service_policy_association': {
+        EXTENSION_LOCATION + '/region_and_service_policy_association': {
             'href-template': '/policies/{policy_id}/OS-ENDPOINT-POLICY/'
             'services/{service_id}/regions/{region_id}',
             'href-vars': {
