@@ -33,6 +33,14 @@ CONF = keystone.conf.CONF
 PROVIDERS = provider_api.ProviderAPIs
 
 
+def _get_id_list_from_ref_list(ref_list):
+    """Get entity IDs from the response"""
+    result_list = []
+    for x in ref_list:
+        result_list.append(x['id'])
+    return result_list
+
+
 class IdentityTestFilteredCase(filtering.FilterTests, test_v3.RestfulTestCase):
     """Test filter enforcement on the v3 Identity API."""
 
@@ -96,12 +104,6 @@ class IdentityTestFilteredCase(filtering.FilterTests, test_v3.RestfulTestCase):
             user_id=self.user1['id'], password=self.user1['password']
         )
 
-    def _get_id_list_from_ref_list(self, ref_list):
-        result_list = []
-        for x in ref_list:
-            result_list.append(x['id'])
-        return result_list
-
     def _set_policy(self, new_policy):
         with open(self.tmpfilename, "w") as policyfile:
             policyfile.write(jsonutils.dumps(new_policy))
@@ -117,10 +119,10 @@ class IdentityTestFilteredCase(filtering.FilterTests, test_v3.RestfulTestCase):
 
         """
         self._set_policy({"identity:list_users": []})
-        url_by_name = '/users?domain_id=%s' % self.domainB['id']
+        url_by_name = '/users?domain_id={}'.format(self.domainB['id'])
         r = self.get(url_by_name, auth=self.auth)
         # We should  get back two users, those in DomainB
-        id_list = self._get_id_list_from_ref_list(r.result.get('users'))
+        id_list = _get_id_list_from_ref_list(r.result.get('users'))
         self.assertIn(self.user2['id'], id_list)
         self.assertIn(self.user3['id'], id_list)
 
@@ -140,28 +142,28 @@ class IdentityTestFilteredCase(filtering.FilterTests, test_v3.RestfulTestCase):
         new_policy = {"identity:list_domains": []}
         self._set_policy(new_policy)
         r = self.get('/domains?enabled=0', auth=self.auth)
-        id_list = self._get_id_list_from_ref_list(r.result.get('domains'))
+        id_list = _get_id_list_from_ref_list(r.result.get('domains'))
         self.assertEqual(1, len(id_list))
         self.assertIn(self.domainC['id'], id_list)
 
         # Try a few ways of specifying 'false'
         for val in ('0', 'false', 'False', 'FALSE', 'n', 'no', 'off'):
-            r = self.get('/domains?enabled=%s' % val, auth=self.auth)
-            id_list = self._get_id_list_from_ref_list(r.result.get('domains'))
+            r = self.get(f'/domains?enabled={val}', auth=self.auth)
+            id_list = _get_id_list_from_ref_list(r.result.get('domains'))
             self.assertEqual([self.domainC['id']], id_list)
 
         # Now try a few ways of specifying 'true' when we should get back
         # the other two domains, plus the default domain
         for val in ('1', 'true', 'True', 'TRUE', 'y', 'yes', 'on'):
-            r = self.get('/domains?enabled=%s' % val, auth=self.auth)
-            id_list = self._get_id_list_from_ref_list(r.result.get('domains'))
+            r = self.get(f'/domains?enabled={val}', auth=self.auth)
+            id_list = _get_id_list_from_ref_list(r.result.get('domains'))
             self.assertEqual(3, len(id_list))
             self.assertIn(self.domainA['id'], id_list)
             self.assertIn(self.domainB['id'], id_list)
             self.assertIn(CONF.identity.default_domain_id, id_list)
 
         r = self.get('/domains?enabled', auth=self.auth)
-        id_list = self._get_id_list_from_ref_list(r.result.get('domains'))
+        id_list = _get_id_list_from_ref_list(r.result.get('domains'))
         self.assertEqual(3, len(id_list))
         self.assertIn(self.domainA['id'], id_list)
         self.assertIn(self.domainB['id'], id_list)
@@ -180,9 +182,9 @@ class IdentityTestFilteredCase(filtering.FilterTests, test_v3.RestfulTestCase):
         new_policy = {"identity:list_domains": []}
         self._set_policy(new_policy)
 
-        my_url = '/domains?enabled&name=%s' % self.domainA['name']
+        my_url = '/domains?enabled&name={}'.format(self.domainA['name'])
         r = self.get(my_url, auth=self.auth)
-        id_list = self._get_id_list_from_ref_list(r.result.get('domains'))
+        id_list = _get_id_list_from_ref_list(r.result.get('domains'))
         self.assertEqual(1, len(id_list))
         self.assertIn(self.domainA['id'], id_list)
         self.assertIs(True, r.result.get('domains')[0]['enabled'])
@@ -200,9 +202,9 @@ class IdentityTestFilteredCase(filtering.FilterTests, test_v3.RestfulTestCase):
         new_policy = {"identity:list_domains": []}
         self._set_policy(new_policy)
 
-        my_url = '/domains?enableds=0&name=%s' % self.domainA['name']
+        my_url = '/domains?enableds=0&name={}'.format(self.domainA['name'])
         r = self.get(my_url, auth=self.auth)
-        id_list = self._get_id_list_from_ref_list(r.result.get('domains'))
+        id_list = _get_id_list_from_ref_list(r.result.get('domains'))
 
         # domainA is returned and it is enabled, since enableds=0 is not the
         # same as enabled=0
@@ -227,7 +229,6 @@ class IdentityTestFilteredCase(filtering.FilterTests, test_v3.RestfulTestCase):
         # token.
         time = timeutils.utcnow()
         with freezegun.freeze_time(time) as frozen_datetime:
-
             self._set_policy({"identity:list_users": []})
             user = self.user1
             user['name'] = '%my%name%'
@@ -239,7 +240,7 @@ class IdentityTestFilteredCase(filtering.FilterTests, test_v3.RestfulTestCase):
             r = self.get(url_by_name, auth=self.auth)
 
             self.assertEqual(1, len(r.result.get('users')))
-            self.assertEqual(user['id'], r.result.get('users')[0]['id'])
+            self.assertIn(user['id'], [x["id"] for x in r.result.get('users')])
 
     def test_inexact_filters(self):
         # Create 20 users
@@ -298,13 +299,19 @@ class IdentityTestFilteredCase(filtering.FilterTests, test_v3.RestfulTestCase):
         url_by_name = '/users?name__endswith=of'
         r = self.get(url_by_name, auth=self.auth)
         self.assertEqual(1, len(r.result.get('users')))
-        self.assertEqual(user_list[7]['id'], r.result.get('users')[0]['id'])
+        self.assertIn(
+            user_list[7]['id'], [x["id"] for x in r.result.get('users')]
+        )
 
         url_by_name = '/users?name__iendswith=OF'
         r = self.get(url_by_name, auth=self.auth)
         self.assertEqual(2, len(r.result.get('users')))
-        self.assertEqual(user_list[7]['id'], r.result.get('users')[0]['id'])
-        self.assertEqual(user_list[10]['id'], r.result.get('users')[1]['id'])
+        self.assertIn(
+            user_list[7]['id'], [x["id"] for x in r.result.get('users')]
+        )
+        self.assertIn(
+            user_list[10]['id'], [x["id"] for x in r.result.get('users')]
+        )
 
         self._delete_test_data('user', user_list)
 
@@ -450,12 +457,7 @@ class IdentityPasswordExpiryFilteredTestCase(
         {operator}:{timestamp}
 
         """
-        url = '/users?password_expires_at={}:{}&password_expires_at={}:{}'.format(
-            first_operator,
-            first_time,
-            second_operator,
-            second_time,
-        )
+        url = f'/users?password_expires_at={first_operator}:{first_time}&password_expires_at={second_operator}:{second_time}'
         return url
 
     def _format_timestamp(self, timestamp):
@@ -482,7 +484,7 @@ class IdentityPasswordExpiryFilteredTestCase(
             'eq',
         )
         resp_users = self.get(expire_at_url).result.get('users')
-        self.assertEqual(self.user2['id'], resp_users[0]['id'])
+        self.assertIn(self.user2['id'], [x["id"] for x in resp_users])
 
         expire_at_url = self._list_users_by_password_expires_at(
             self._format_timestamp(
@@ -490,9 +492,10 @@ class IdentityPasswordExpiryFilteredTestCase(
             ),
             'neq',
         )
-        resp_users = self.get(expire_at_url).result.get('users')
-        self.assertEqual(self.user['id'], resp_users[0]['id'])
-        self.assertEqual(self.user3['id'], resp_users[1]['id'])
+        resp_users = self.get(expire_at_url).result.get("users")
+        id_list = _get_id_list_from_ref_list(resp_users)
+        self.assertIn(self.user['id'], id_list)
+        self.assertIn(self.user3['id'], id_list)
 
     def test_list_users_by_password_expires_before(self):
         """Ensure users can be filtered on lt and lte.
@@ -508,8 +511,9 @@ class IdentityPasswordExpiryFilteredTestCase(
             'lt',
         )
         resp_users = self.get(expire_before_url).result.get('users')
-        self.assertEqual(self.user['id'], resp_users[0]['id'])
-        self.assertEqual(self.user2['id'], resp_users[1]['id'])
+        id_list = _get_id_list_from_ref_list(resp_users)
+        self.assertIn(self.user['id'], id_list)
+        self.assertIn(self.user2['id'], id_list)
 
         expire_before_url = self._list_users_by_password_expires_at(
             self._format_timestamp(
@@ -518,8 +522,9 @@ class IdentityPasswordExpiryFilteredTestCase(
             'lte',
         )
         resp_users = self.get(expire_before_url).result.get('users')
-        self.assertEqual(self.user['id'], resp_users[0]['id'])
-        self.assertEqual(self.user2['id'], resp_users[1]['id'])
+        id_list = _get_id_list_from_ref_list(resp_users)
+        self.assertIn(self.user['id'], id_list)
+        self.assertIn(self.user2['id'], id_list)
 
     def test_list_users_by_password_expires_after(self):
         """Ensure users can be filtered on gt and gte.
@@ -535,7 +540,7 @@ class IdentityPasswordExpiryFilteredTestCase(
             'gt',
         )
         resp_users = self.get(expire_after_url).result.get('users')
-        self.assertEqual(self.user3['id'], resp_users[0]['id'])
+        self.assertIn(self.user3['id'], [x["id"] for x in resp_users])
 
         expire_after_url = self._list_users_by_password_expires_at(
             self._format_timestamp(
@@ -544,8 +549,9 @@ class IdentityPasswordExpiryFilteredTestCase(
             'gte',
         )
         resp_users = self.get(expire_after_url).result.get('users')
-        self.assertEqual(self.user2['id'], resp_users[0]['id'])
-        self.assertEqual(self.user3['id'], resp_users[1]['id'])
+        id_list = _get_id_list_from_ref_list(resp_users)
+        self.assertIn(self.user2['id'], id_list)
+        self.assertIn(self.user3['id'], id_list)
 
     def test_list_users_by_password_expires_interval(self):
         """Ensure users can be filtered on time intervals.
@@ -568,7 +574,7 @@ class IdentityPasswordExpiryFilteredTestCase(
             'gt',
         )
         resp_users = self.get(expire_interval_url).result.get('users')
-        self.assertEqual(self.user2['id'], resp_users[0]['id'])
+        self.assertIn(self.user2['id'], [x["id"] for x in resp_users])
 
         expire_interval_url = self._list_users_by_multiple_password_expires_at(
             self._format_timestamp(
@@ -581,7 +587,7 @@ class IdentityPasswordExpiryFilteredTestCase(
             'lte',
         )
         resp_users = self.get(expire_interval_url).result.get('users')
-        self.assertEqual(self.user2['id'], resp_users[0]['id'])
+        self.assertIn(self.user2['id'], [x["id"] for x in resp_users])
 
     def test_list_users_by_password_expires_with_bad_operator_fails(self):
         """Ensure an invalid operator returns a Bad Request.
@@ -656,8 +662,7 @@ class IdentityPasswordExpiryFilteredTestCase(
         """
         url = (
             '/groups/' + self.group_id + '/users'
-            '?password_expires_at=%s:%s&password_expires_at=%s:%s'
-            % (first_operator, first_time, second_operator, second_time)
+            f'?password_expires_at={first_operator}:{first_time}&password_expires_at={second_operator}:{second_time}'
         )
         return url
 
@@ -682,7 +687,7 @@ class IdentityPasswordExpiryFilteredTestCase(
             'eq',
         )
         resp_users = self.get(expire_at_url).result.get('users')
-        self.assertEqual(self.user2['id'], resp_users[0]['id'])
+        self.assertIn(self.user2['id'], [x["id"] for x in resp_users])
 
         expire_at_url = self._list_users_in_group_by_password_expires_at(
             self._format_timestamp(
@@ -691,7 +696,7 @@ class IdentityPasswordExpiryFilteredTestCase(
             'neq',
         )
         resp_users = self.get(expire_at_url).result.get('users')
-        self.assertEqual(self.user3['id'], resp_users[0]['id'])
+        self.assertIn(self.user3['id'], [x["id"] for x in resp_users])
 
     def test_list_users_in_group_by_password_expires_before(self):
         """Ensure users in a group can be filtered on with lt and lte.
@@ -707,7 +712,7 @@ class IdentityPasswordExpiryFilteredTestCase(
             'lt',
         )
         resp_users = self.get(expire_before_url).result.get('users')
-        self.assertEqual(self.user2['id'], resp_users[0]['id'])
+        self.assertIn(self.user2['id'], [x["id"] for x in resp_users])
 
         expire_before_url = self._list_users_in_group_by_password_expires_at(
             self._format_timestamp(
@@ -716,7 +721,7 @@ class IdentityPasswordExpiryFilteredTestCase(
             'lte',
         )
         resp_users = self.get(expire_before_url).result.get('users')
-        self.assertEqual(self.user2['id'], resp_users[0]['id'])
+        self.assertIn(self.user2['id'], [x["id"] for x in resp_users])
 
     def test_list_users_in_group_by_password_expires_after(self):
         """Ensure users in a group can be filtered on with gt and gte.
@@ -732,7 +737,7 @@ class IdentityPasswordExpiryFilteredTestCase(
             'gt',
         )
         resp_users = self.get(expire_after_url).result.get('users')
-        self.assertEqual(self.user3['id'], resp_users[0]['id'])
+        self.assertIn(self.user3['id'], [x["id"] for x in resp_users])
 
         expire_after_url = self._list_users_in_group_by_password_expires_at(
             self._format_timestamp(
@@ -741,8 +746,9 @@ class IdentityPasswordExpiryFilteredTestCase(
             'gte',
         )
         resp_users = self.get(expire_after_url).result.get('users')
-        self.assertEqual(self.user2['id'], resp_users[0]['id'])
-        self.assertEqual(self.user3['id'], resp_users[1]['id'])
+        id_list = _get_id_list_from_ref_list(resp_users)
+        self.assertIn(self.user2['id'], id_list)
+        self.assertIn(self.user3['id'], id_list)
 
     def test_list_users_in_group_by_password_expires_interval(self):
         """Ensure users in a group can be filtered on time intervals.
@@ -767,8 +773,9 @@ class IdentityPasswordExpiryFilteredTestCase(
             )
         )
         resp_users = self.get(expire_interval_url).result.get('users')
-        self.assertEqual(self.user2['id'], resp_users[0]['id'])
-        self.assertEqual(self.user3['id'], resp_users[1]['id'])
+        id_list = _get_id_list_from_ref_list(resp_users)
+        self.assertIn(self.user2['id'], id_list)
+        self.assertIn(self.user3['id'], id_list)
 
         expire_interval_url = (
             self._list_users_in_group_by_multiple_password_expires_at(
@@ -783,8 +790,9 @@ class IdentityPasswordExpiryFilteredTestCase(
             )
         )
         resp_users = self.get(expire_interval_url).result.get('users')
-        self.assertEqual(self.user2['id'], resp_users[0]['id'])
-        self.assertEqual(self.user3['id'], resp_users[1]['id'])
+        id_list = _get_id_list_from_ref_list(resp_users)
+        self.assertIn(self.user2['id'], id_list)
+        self.assertIn(self.user3['id'], id_list)
 
     def test_list_users_in_group_by_password_expires_bad_operator_fails(self):
         """Ensure an invalid operator returns a Bad Request.
@@ -896,17 +904,17 @@ class IdentityTestListLimitCase(IdentityTestFilteredCase):
         if entity == 'policy':
             plural = 'policies'
         else:
-            plural = '%ss' % entity
+            plural = f'{entity}s'
 
-        self._set_policy({"identity:list_%s" % plural: []})
+        self._set_policy({f"identity:list_{plural}": []})
         self.config_fixture.config(list_limit=5)
         self.config_fixture.config(group=driver, list_limit=None)
-        r = self.get('/%s' % plural, auth=self.auth)
+        r = self.get(f'/{plural}', auth=self.auth)
         self.assertEqual(5, len(r.result.get(plural)))
         self.assertIs(r.result.get('truncated'), True)
 
         self.config_fixture.config(group=driver, list_limit=4)
-        r = self.get('/%s' % plural, auth=self.auth)
+        r = self.get(f'/{plural}', auth=self.auth)
         self.assertEqual(4, len(r.result.get(plural)))
         self.assertIs(r.result.get('truncated'), True)
 
